@@ -1,29 +1,23 @@
-from multiprocessing import Process, Pipe, connection, get_context, Array
+from typing import Any, Union, List, Tuple, Dict, Callable, Optional
+from multiprocessing import Pipe, connection, get_context, Array
 from collections import namedtuple
-import enum
 import logging
 import platform
 import time
-import math
 import copy
 import traceback
-import threading
 import numpy as np
 import torch
 import ctypes
 import pickle
 import cloudpickle
-from functools import partial
 from easydict import EasyDict
 from types import MethodType
-from typing import Any, Union, List, Tuple, Iterable, Dict, Callable, Optional
 
-from ding.torch_utils import to_tensor, to_ndarray, to_list
 from ding.utils import PropagatingThread, LockContextType, LockContext, ENV_MANAGER_REGISTRY
 from .base_env_manager import BaseEnvManager, EnvState, retry_wrapper, timeout_wrapper
 
 _NTYPE_TO_CTYPE = {
-    np.bool: ctypes.c_bool,
     np.bool_: ctypes.c_bool,
     np.uint8: ctypes.c_uint8,
     np.uint16: ctypes.c_uint16,
@@ -275,7 +269,7 @@ class AsyncSubprocessEnvManager(BaseEnvManager):
         Return:
             A dictionary with observations and their environment IDs.
         Note:
-            The observations are returned in torch.Tensor.
+            The observations are returned in np.ndarray.
         Example:
             >>>     obs_dict = env_manager.ready_obs
             >>>     actions_dict = {env_id: model.forward(obs) for env_id, obs in obs_dict.items())}
@@ -338,7 +332,7 @@ class AsyncSubprocessEnvManager(BaseEnvManager):
         # reset env
         reset_thread_list = []
         for i, env_id in enumerate(reset_env_list):
-            self._env_states[env_id] == EnvState.RESET
+            self._env_states[env_id] = EnvState.RESET
             # set seed
             if self._env_seed[env_id] is not None:
                 try:
