@@ -273,7 +273,10 @@ def MLP(
 
         you can refer to nn.linear (https://pytorch.org/docs/master/generated/torch.nn.Linear.html)
     """
-    assert layer_num > 0, layer_num
+    assert layer_num >= 0, layer_num
+    if layer_num == 0:
+        return sequential_pack([nn.Identity()])
+
     channels = [in_channels] + [hidden_channels] * (layer_num - 1) + [out_channels]
     if layer_fn is None:
         layer_fn = nn.Linear
@@ -441,7 +444,6 @@ def binary_encode(y: torch.Tensor, max_val: torch.Tensor) -> torch.Tensor:
     """
     assert (max_val > 0)
     x = y.clamp(0, max_val)
-    B = x.shape[0]
     L = int(math.log(max_val, 2)) + 1
     binary = []
     one = torch.ones_like(x)
