@@ -3,7 +3,9 @@ from .base_serial_collector import ISerialCollector, create_serial_collector, ge
     to_tensor_transitions
 from .sample_serial_collector import SampleCollector
 from .episode_serial_collector import EpisodeCollector
+from .episode_one_vs_one_serial_collector import Episode1v1Collector
 from .base_serial_evaluator import BaseSerialEvaluator
+from .one_vs_one_serial_evaluator import OnevOneEvaluator
 # parallel
 from .base_parallel_collector import BaseCollector, create_parallel_collector, get_parallel_collector_cls
 from .zergling_collector import ZerglingCollector
