@@ -1,16 +1,15 @@
+from typing import Any, Union, Callable, List, Dict, Optional, Tuple
 import time
 import copy
 import logging
-from typing import Any, Union, Callable, List, Dict, Optional, Tuple
 from functools import partial
 from easydict import EasyDict
 from collections import namedtuple
 
-from ding.torch_utils import build_checkpoint_helper, CountVar, auto_checkpoint, build_log_buffer
-from ding.utils import build_logger, EasyTimer, pretty_print, deep_merge_dicts, import_module, LEARNER_REGISTRY, \
-    get_rank, get_world_size
-from ding.utils.autolog import LoggedValue, LoggedModel, NaturalTime, TickTime, TimeMode
-from ding.utils.data import AsyncDataLoader, default_collate
+from ding.torch_utils import CountVar, auto_checkpoint, build_log_buffer
+from ding.utils import build_logger, EasyTimer, import_module, LEARNER_REGISTRY, get_rank, get_world_size
+from ding.utils.autolog import LoggedValue, LoggedModel, TickTime
+from ding.utils.data import AsyncDataLoader
 from .learner_hook import build_learner_hook_by_cfg, add_learner_hook, merge_hooks, LearnerHook
 logging.info('')  # necessary
 
@@ -19,12 +18,12 @@ logging.info('')  # necessary
 class BaseLearner(object):
     r"""
     Overview:
-        Base class for model learning.
+        Base class for policy learning.
     Interface:
         train, call_hook, register_hook, save_checkpoint, start, setup_dataloader, close
     Property:
-        learn_info, priority_info, last_iter, name, rank, world_size, policy
-        monitor, log_buffer, logger, tb_logger
+        learn_info, priority_info, last_iter, train_iter, rank, world_size, policy
+        monitor, log_buffer, logger, tb_logger, ckpt_name, exp_name, instance_name
     """
 
     @classmethod
@@ -53,15 +52,20 @@ class BaseLearner(object):
             policy: namedtuple = None,
             tb_logger: Optional['SummaryWriter'] = None,  # noqa
             dist_info: Tuple[int, int] = None,
+            exp_name: Optional[str] = 'default_experiment',
+            instance_name: Optional[str] = 'learner',
     ) -> None:
         """
         Overview:
-            Init method. Load config and use ``self._cfg`` to build common learner components,
-            e.g. logger, hooks.
-            Policy is not initialized here, but set afterwards through policy setter.
+            Initialization method, build common learner components according to cfg, such as hook, wrapper and so on.
         Arguments:
-            - cfg (:obj:`EasyDict`): Learner config, you can view `cfg <../../../configuration/index.html>`_ for ref.
-            - rank (:obj:`int`): Process number in multi-gpu training
+            - cfg (:obj:`EasyDict`): Learner config, you can refer cls.config for details.
+            - policy (:obj:`namedtuple`): A collection of policy function of learn mode. And policy can also be \
+                initialized when runtime.
+            - tb_logger (:obj:`SummaryWriter`): Tensorboard summary writer.
+            - dist_info (:obj:`Tuple[int, int]`): Multi-GPU distributed training information.
+            - exp_name (:obj:`str`): Experiment name, which is used to indicate output directory.
+            - instance_name (:obj:`str`): Instance name, which should be unique among different learners.
         Notes:
             If you want to debug in sync CUDA mode, please add the following code at the beginning of ``__init__``.
 
@@ -70,7 +74,8 @@ class BaseLearner(object):
                 os.environ['CUDA_LAUNCH_BLOCKING'] = "1"  # for debug async CUDA
         """
         self._cfg = cfg
-        self._instance_name = self._name + '_' + time.ctime().replace(' ', '_').replace(':', '_')
+        self._exp_name = exp_name
+        self._instance_name = instance_name
         self._ckpt_name = None
         self._timer = EasyTimer()
 
@@ -90,12 +95,18 @@ class BaseLearner(object):
         # Only rank == 0 learner needs monitor and tb_logger, others only need text_logger to display terminal output.
         if self._rank == 0:
             if tb_logger is not None:
-                self._logger, _ = build_logger('./log/learner', 'learner', need_tb=False)
+                self._logger, _ = build_logger(
+                    './{}/log/{}'.format(self._exp_name, self._instance_name), self._instance_name, need_tb=False
+                )
                 self._tb_logger = tb_logger
             else:
-                self._logger, self._tb_logger = build_logger('./log/learner', 'learner')
+                self._logger, self._tb_logger = build_logger(
+                    './{}/log/{}'.format(self._exp_name, self._instance_name), self._instance_name
+                )
         else:
-            self._logger, _ = build_logger('./log/learner', 'learner', need_tb=False)
+            self._logger, _ = build_logger(
+                './{}/log/{}'.format(self._exp_name, self._instance_name), self._instance_name, need_tb=False
+            )
             self._tb_logger = None
         self._log_buffer = {
             'scalar': build_log_buffer(),
@@ -191,7 +202,12 @@ class BaseLearner(object):
         log_vars = self._policy.forward(data)
 
         # Update replay buffer's priority info
-        priority = log_vars.pop('priority', None)
+        if isinstance(log_vars, dict):
+            priority = log_vars.pop('priority', None)
+        elif isinstance(log_vars, list):
+            priority = log_vars[-1].pop('priority', None)
+        else:
+            raise TypeError("not support type for log_vars: {}".format(type(log_vars)))
         if priority is not None:
             replay_buffer_idx = [d.get('replay_buffer_idx', None) for d in data]
             replay_unique_id = [d.get('replay_unique_id', None) for d in data]
@@ -202,22 +218,25 @@ class BaseLearner(object):
             }
         # Discriminate vars in scalar, scalars and histogram type
         # Regard a var as scalar type by default. For scalars and histogram type, must annotate by prefix "[xxx]"
-        scalars_vars, histogram_vars = {}, {}
-        for k in list(log_vars.keys()):
-            if "[scalars]" in k:
-                new_k = k.split(']')[-1]
-                scalars_vars[new_k] = log_vars.pop(k)
-            elif "[histogram]" in k:
-                new_k = k.split(']')[-1]
-                histogram_vars[new_k] = log_vars.pop(k)
-        # Update log_buffer
-        self._log_buffer['scalar'].update(log_vars)
-        self._log_buffer['scalars'].update(scalars_vars)
-        self._log_buffer['histogram'].update(histogram_vars)
-
         self._collector_envstep = envstep
-        self.call_hook('after_iter')
-        self._last_iter.add(1)
+        if isinstance(log_vars, dict):
+            log_vars = [log_vars]
+        for elem in log_vars:
+            scalars_vars, histogram_vars = {}, {}
+            for k in list(elem.keys()):
+                if "[scalars]" in k:
+                    new_k = k.split(']')[-1]
+                    scalars_vars[new_k] = elem.pop(k)
+                elif "[histogram]" in k:
+                    new_k = k.split(']')[-1]
+                    histogram_vars[new_k] = elem.pop(k)
+            # Update log_buffer
+            self._log_buffer['scalar'].update(elem)
+            self._log_buffer['scalars'].update(scalars_vars)
+            self._log_buffer['histogram'].update(histogram_vars)
+
+            self.call_hook('after_iter')
+            self._last_iter.add(1)
 
     @auto_checkpoint
     def start(self) -> None:
@@ -382,7 +401,11 @@ class BaseLearner(object):
         return self._tb_logger
 
     @property
-    def name(self) -> str:
+    def exp_name(self) -> str:
+        return self._exp_name
+
+    @property
+    def instance_name(self) -> str:
         return self._instance_name
 
     @property
