@@ -20,11 +20,11 @@ ATARIENV_INFO_DICT = {
             },
         ),
         act_space=EnvElementInfo(
-            shape=(6, ),
+            shape=(1, ),
             value={
                 'min': 0,
                 'max': 6,
-                'dtype': np.float32
+                'dtype': np.int64
             },
         ),
         rew_space=EnvElementInfo(
@@ -48,11 +48,11 @@ ATARIENV_INFO_DICT = {
             },
         ),
         act_space=EnvElementInfo(
-            shape=(6, ),
+            shape=(1, ),
             value={
                 'min': 0,
                 'max': 6,
-                'dtype': np.float32
+                'dtype': np.int64
             },
         ),
         rew_space=EnvElementInfo(
@@ -76,10 +76,38 @@ ATARIENV_INFO_DICT = {
             },
         ),
         act_space=EnvElementInfo(
-            shape=(6, ),
+            shape=(1, ),
             value={
                 'min': 0,
                 'max': 6,
+                'dtype': np.int64,
+            },
+        ),
+        rew_space=EnvElementInfo(
+            shape=1,
+            value={
+                'min': -1,
+                'max': 1,
+                'dtype': np.float32
+            },
+        ),
+        use_wrappers=None,
+    ),
+    'EnduroNoFrameskip-v4': BaseEnvInfo(
+        agent_num=1,
+        obs_space=EnvElementInfo(
+            shape=(210, 160, 3),
+            value={
+                'min': 0,
+                'max': 255,
+                'dtype': np.float32
+            },
+        ),
+        act_space=EnvElementInfo(
+            shape=(1, ),
+            value={
+                'min': 0,
+                'max': 9,
                 'dtype': np.float32
             },
         ),
@@ -104,11 +132,11 @@ ATARIENV_INFO_DICT = {
             },
         ),
         act_space=EnvElementInfo(
-            shape=(18, ),
+            shape=(1, ),
             value={
                 'min': 0,
                 'max': 18,
-                'dtype': np.float32
+                'dtype': np.int64,
             },
         ),
         rew_space=EnvElementInfo(
