@@ -2,6 +2,7 @@ from .cartpole_dqn_config import cartpole_dqn_config, cartpole_dqn_create_config
 from .cartpole_a2c_config import cartpole_a2c_config, cartpole_a2c_create_config
 from .cartpole_impala_config import cartpole_impala_config, cartpole_impala_create_config
 from .cartpole_ppo_config import cartpole_ppo_config, cartpole_ppo_create_config
+from .cartpole_ppo_offpolicy_config import cartpole_ppo_offpolicy_config, cartpole_ppo_offpolicy_create_config
 from .cartpole_rainbow_config import cartpole_rainbow_config, cartpole_rainbow_create_config
 from .cartpole_iqn_config import cartpole_iqn_config, cartpole_iqn_create_config
 from .cartpole_c51_config import cartpole_c51_config, cartpole_c51_create_config
@@ -9,4 +10,5 @@ from .cartpole_qrdqn_config import cartpole_qrdqn_config, cartpole_qrdqn_create_
 from .cartpole_sqn_config import cartpole_sqn_config, cartpole_sqn_create_config
 from .cartpole_ppg_config import cartpole_ppg_config, cartpole_ppg_create_config
 from .cartpole_r2d2_config import cartpole_r2d2_config, cartpole_r2d2_create_config
+from .cartpole_acer_config import cartpole_acer_config, cartpole_acer_create_config
 # from .cartpole_ppo_default_loader import cartpole_ppo_default_loader
